#
# spec file for package python-mailman-hyperkitty
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Always only build one flavor: primary python for TW, python311 from the SLE15 python module for 15.x
%if 0%{?suse_version} >= 1550
%define pythons python3
%else
%{?sle15_python_module_pythons}
%endif
%global mypython %pythons
%global mypython_sitelib %{expand:%%{%{mypython}_sitelib}}

Name:           python-mailman-hyperkitty
Version:        1.2.1
Release:        4.3
Summary:        Mailman archiver plugin for HyperKitty
License:        GPL-3.0-only
URL:            https://gitlab.com/mailman/mailman-hyperkitty/
Source:         https://files.pythonhosted.org/packages/source/m/mailman-hyperkitty/mailman-hyperkitty-%{version}.tar.gz
# https://gitlab.com/mailman/mailman-hyperkitty/-/issues/28
Patch0:         python-mailman-hyperkitty-fix-archiver-test.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  (mailman3 >= 3.3.5 with %{mypython}-mailman3)
BuildRequires:  %{python_module nose2}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.interface}
# /SECTION

%description
Mailman archiver plugin for HyperKitty

%package -n %{mypython}-mailman-hyperkitty
Summary:        Mailman archiver plugin for HyperKitty
Requires:       %{mypython}-requests
Requires:       %{mypython}-zope.interface
Requires:       (mailman3 >= 3.3.5 with %{mypython}-mailman3)

%description -n %{mypython}-mailman-hyperkitty
Mailman archiver plugin for HyperKitty

%prep
%autosetup -n mailman-hyperkitty-%{version} -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -m nose2 -v

%files -n %{mypython}-mailman-hyperkitty
%doc README.rst mailman-hyperkitty.cfg
%license LICENSE.txt
%{mypython_sitelib}/mailman_hyperkitty
%{mypython_sitelib}/mailman_hyperkitty-%{version}.dist-info

%changelog
* Thu Feb 29 2024 Ben Greiner <code@bnavigator.de>
- Simplify python flavor selection
  * Go back to primary python3 on Tumbleweed
  * Use SLE15 python module pythons on 15.x
- Replace pseudo python singlespec rewriter in order to not give
  the wrong impression
* Wed Feb 28 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Build for Python 3.12
* Sat Jul  1 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix requirement for mailman3 and python modules
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.1
- Use sle15_python_module_pythons
- Removed python-mailman-hyperkitty-no-mock.patch
* Mon Jul  4 2022 Ben Greiner <code@bnavigator.de>
- Go back to python39 -- highest supported Python by mailman3
* Thu Jun  9 2022 Andreas Schneider <asn@cryptomilk.org>
- Fix BR for mailman3 (package has been renamed)
- Fix test_archive_message_with_surrogates
  * Added python-mailman-hyperkitty-fix-archiver-test.patch
* Thu May 26 2022 pgajdos@suse.com
- do not use python-mock for build
- added patches
  fix https://gitlab.com/mailman/mailman-hyperkitty/-/issues/28
  + python-mailman-hyperkitty-no-mock.patch
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.0
  * Update the authentication to call Hyperkitty using the API key as a part of
    Authorization HTTP header instead of url parameter.
- Removed obsolete python-mailman-hyperkitty-reflect-changes-in-mailman-core.patch
* Tue May  4 2021 Ben Greiner <code@bnavigator.de>
- restrict to primary python3 flavor due to mailman
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Nov 27 2019 pgajdos@suse.com
- ship mailman-hyperkitty.cfg, in doc for now
* Thu Nov 14 2019 pgajdos@suse.com
- fix testsuite
- added patches
  https://gitlab.com/mailman/mailman-hyperkitty/commit/84e05811fb71aa105fd85fd14399bff813ed744d
  + python-mailman-hyperkitty-reflect-changes-in-mailman-core.patch
* Thu Nov 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use nose2 to run the tests as the package can't use pytest
* Wed Nov 13 2019 pgajdos@suse.com
- initial version 1.1.0 [SLE-7686]
